/*
 *   Licensed to the Apache Software Foundation (ASF) under one
 *   or more contributor license agreements.  See the NOTICE file
 *   distributed with this work for additional information
 *   regarding copyright ownership.  The ASF licenses this file
 *   to you under the Apache License, Version 2.0 (the
 *   "License"); you may not use this file except in compliance
 *   with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing,
 *   software distributed under the License is distributed on an
 *   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *   KIND, either express or implied.  See the License for the
 *   specific language governing permissions and limitations
 *   under the License.
 *
 */

package org.apache.directory.ldap.client.api.message;


import org.apache.directory.shared.ldap.name.DN;
import org.apache.directory.shared.ldap.name.RDN;


/**
 * Class for representing client's modifyDn operation request.
 *
 * @author <a href="mailto:dev@directory.apache.org">Apache Directory Project</a>
 * @version $Rev$, $Date$
 */
public class ModifyDnRequest extends AbstractRequest implements RequestWithResponse, AbandonableRequest
{
    /** the entry's DN to be changed */
    private DN entryDn;

    /** the new RDN */
    private RDN newRdn;

    /** target entry's new parent DN */
    private DN newSuperior;

    /** flag to indicate whether to delete the old RDN */
    private boolean deleteOldRdn = false;


    public ModifyDnRequest()
    {
        super();
    }


    public DN getEntryDn()
    {
        return entryDn;
    }


    public void setEntryDn( DN entryDn )
    {
        this.entryDn = entryDn;
    }


    public RDN getNewRdn()
    {
        return newRdn;
    }


    public void setNewRdn( RDN newRdn )
    {
        this.newRdn = newRdn;
    }


    public DN getNewSuperior()
    {
        return newSuperior;
    }


    public void setNewSuperior( DN newSuperior )
    {
        this.newSuperior = newSuperior;
    }


    public boolean isDeleteOldRdn()
    {
        return deleteOldRdn;
    }


    public void setDeleteOldRdn( boolean deleteOldRdn )
    {
        this.deleteOldRdn = deleteOldRdn;
    }

    
}
